#
# spec file for package qgroundcontrol
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           qgroundcontrol
Version:        3.3.2
Release:        lp152.3.10
Summary:        An operator control unit / ground control software for micro air vehicles
License:        GPL-3.0-only
Group:          Other
Url:            http://www.qgroundcontrol.org/
Source0:        qgroundcontrol-%{version}.tar.xz
Patch2:         fix-install.patch
Patch3:         use_system_qwt.patch
# ModemManager has the broken design to grab any serial port first
# as background daemon. this breaks any other app which needs to access the device
# on boot up (for firmware update here)
Conflicts:      ModemManager
%if 0%{?fedora_version}
BuildRequires:  python2
BuildRequires:  systemd-devel
%else
BuildRequires:  libudev-devel
%endif
BuildRequires:  libqt5-qtlocation-private-headers-devel

BuildRequires:  pkgconfig(Qt5Core) >= 5.7
BuildRequires:  pkgconfig(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Positioning)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(Qt5Qwt6)
%endif

BuildRequires:  SDL2-devel
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libicu-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libudev-devel
BuildRequires:  openssl-devel
# is not building atm
#BuildRequires:  libxbee3-devel
BuildRequires:  fdupes

#qml deps
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols

%description
QGroundControl is an operator control unit / ground control software
for micro air vehicles. It allows to visualize and control a micro
air vehicle during development and operation, both indoors and
outdoors. With a flexible software architecture, it supports multiple
MAV types/autopilot projects.

%prep
%setup -q
%patch2 -p1
%if 0%{?suse_version} >= 1500
%patch3 -p1
%endif
mkdir build

%build
cd build
qmake-qt5 ../qgroundcontrol.pro
make %{?_smp_mflags}

%install
cd build
mkdir -p %{buildroot}/%{_bindir}
mkdir -p %{buildroot}/%{_datadir}/%{name}/
cp -R release/flightgear %{buildroot}/%{_datadir}/%{name}/
install -p -m 755 release/QGroundControl %{buildroot}/%{_bindir}/
mkdir -p %{buildroot}/usr/share/{applications,pixmaps}
install -p -m 0644 ../deploy/qgroundcontrol.desktop %{buildroot}/usr/share/applications/
install -p -m 0644 ../resources/icons/qgroundcontrol.png %{buildroot}/usr/share/pixmaps/
sed -i -e 's/^Categories=.*/Categories=Development;Building;/' %{buildroot}/usr/share/applications/qgroundcontrol.desktop
%fdupes %{buildroot}%{_prefix}

%files
%defattr(0644,root,root,-)
%doc COPYING.md README.md
%attr(0755,root,root) %{_bindir}/QGroundControl
%{_datadir}/%{name}
/usr/share/applications/*
/usr/share/pixmaps/*

%changelog
* Thu May  3 2018 adrian@suse.de
- update to version 3.3.2
  * crash fixes and debugging improvements
* Fri Apr 13 2018 adrian@suse.de
- update to version 3.3.1
  * minor enhancements and bugfixes
* Wed Mar  7 2018 adrian@suse.de
- get rid of espeak
- use system qwt (submission by alois use_system_qwt.patch)
- add gstreamer dependencies
* Wed Mar  7 2018 adrian@suse.de
- update to version 3.3.0
  * Settings
  - Local NMEA GPS device support.
  - Video Recording save settings.
  * Setup
  - Parameter Editor - Searching updates as you type characters for near immediate response to searches.
  - Joystick - Android joystick support.
  * Plan
  - NEW - Structure Scan Pattern - Create a multi-layered flight pattern that captures images over vertical surfaces (polygonal or circular). Used for 3d model generation or vertical surface inspection.
  - Fixed Wing Landing Pattern - You can now adjust the distance from the loiter to land point by either distance or glide slope fall rate.
  - PX4 GeoFence and Rally Point support.
  - Terrain height display in lower Mission Item altitude display
  * Fly
  - Start/Stop video recording.
  - Better display of vehicle icons when connected to multiple vehicles.
  - Multi-Vehicle View supports commands which apply to all vehicles.
  - Displays vehicles reported from ADS-B sensor.
  * Analyze
  - Mavlink console - New support for communicating with Mavlink console.
  - Log Download - Moved from Menu to Analyze view.
- drop merged qt 5.10 fix (5923.patch)
* Mon Jan  1 2018 adrian@suse.de
- update to version 3.2.7
  * Bring fixes from master to Stable
  * Remove debuggable to hopefully get back auto-stable build update
- fixing build with Qt 5.10 with patch based on upstream pull request
  (5923.patch)
* Mon Nov  6 2017 adrian@suse.de
- update to version 3.2.5
* Thu Oct 12 2017 jengelh@inai.de
- Trim project history from description.
  Replace %%__-type macro indirections.
  Avoid running fdupes across partition boundaries.
* Wed Aug  9 2017 adrian@suse.de
- update to verion 3.2.4
* Mon Feb 27 2017 adrian@suse.de
- add desktop file again
* Fri Feb 17 2017 adrian@suse.de
- update to version 3.1.3
* Fri Oct 28 2016 adrian@suse.de
- update to version 3.0.2
* Wed Jul 27 2016 adrian@suse.de
- update to version 3.0.0
* Wed May 11 2016 adrian@suse.de
- update to version 2.9.7b
  * Fixed condition for arming button
* Tue May 10 2016 adrian@suse.de
- update to version 2.9.7
  * Fix takeoff logic
  * flight display updates
  * PX4: Fix guided mode interaction
* Mon May  9 2016 adrian@suse.de
- update to version 2.9.6
  * adds a configurable mag calibration for PX4
  * Flight mode updates for APM
  * Simpler mag calibration for PX4
  * (Many changes for mobile version, no effect in this build)
* Fri Feb 26 2016 adrian@suse.de
- update to version 2.9.4
  * looks like feature release, but no changelog
* Mon Feb  1 2016 adrian@suse.de
- update to version 2.9.2
  * bugfix release
* Mon Jan 25 2016 adrian@suse.de
- update to version 2.9.0
  * auto-connect
  * full PX4 and APM stack support including config
  * general improvement
- add conflict to ModemManager, tired of the caused breakage
  (is anyone still using modems at all?)
* Tue Jan  5 2016 adrian@suse.de
- update to version 2.8.0
  * MainWindow
  * Major rewrite of Fly and Mission Editor views
  * Desktop widgets now float instead of dock
  * New Joystick Config
  * PX4 Flow Config
  * Search support
  * Reset to default
  * Flash of APM Stack firmware
  * Flash of PX4 Flow support custom firmware
  * Major visual overhaul
  * Arm/Disarm and change Flight Mode from toolbar
  * Major work on ui display with multiple screen sizes
  * Android builds are now very usable
  * New Travis/Appveyor CI build system
* Thu Aug 20 2015 adrian@suse.de
- update to version 2.7.1
* Mon Jul 27 2015 adrian@suse.de
- update to version 2.6
* Wed Mar 25 2015 adrian@suse.de
- update to version 2.3
- fix build
* Thu Dec 25 2014 christoph@stop.pe
- Initial version
